// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.searchads360.v0.resources;

import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.SearchAds360.V0.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/searchads360/v0/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "GenderViewProto";
option java_package = "com.google.ads.searchads360.v0.resources";
option objc_class_prefix = "GASA360";
option php_namespace = "Google\\Ads\\SearchAds360\\V0\\Resources";
option ruby_package = "Google::Ads::SearchAds360::V0::Resources";

// Proto file describing the gender view resource.

// A gender view.
// The gender_view resource reflects the effective serving state, rather than
// what criteria were added. An ad group without gender criteria by default
// shows to all genders, so all genders appear in gender_view with stats.
message GenderView {
  option (google.api.resource) = {
    type: "searchads360.googleapis.com/GenderView"
    pattern: "customers/{customer_id}/genderViews/{ad_group_id}~{criterion_id}"
  };

  // Output only. The resource name of the gender view.
  // Gender view resource names have the form:
  //
  // `customers/{customer_id}/genderViews/{ad_group_id}~{criterion_id}`
  string resource_name = 1 [
    (google.api.field_behavior) = OUTPUT_ONLY,
    (google.api.resource_reference) = {
      type: "searchads360.googleapis.com/GenderView"
    }
  ];
}
